glob

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 22, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ExpandPatterns

func ExpandPatterns(root string, patterns []Pattern) ([]string, error)

ExpandPatterns expands the patterns relative to the given root directory and returns a sorted, deduplicated list of matching file paths (relative to root).

Types

type Pattern

type Pattern struct {
	Raw     string
	Negated bool
}

Pattern represents a single glob pattern, either include or exclude.

Jump to